Improve this doc View Source

NOTE: this is not an injectable instance, just a globally available function.

Method for serializing common angular objects (scope, elements, etc..) into strings, useful for debugging.

This method is also available on window, where it can be used to display objects on debug console.

## Usage

`angular.mock.dump(object);`

### Arguments

Param | Type | Details
--- | --- | ---
object | * | any object to turn into string.

### Returns

string | a serialized string of the argument